@@ -1,6 +1,14 @@
 /**
  * @file
  * @brief Graphviz context library
+ * @ingroup gvc_api
+ *
+ * **libgvc** provides a context for applications wishing to manipulate
+ * and render graphs. It provides command line parsing,
+ * common rendering code, and a plugin mechanism for renderers.
+ *
+ * [man 3 gvc](https://graphviz.org/pdf/gvc.3.pdf)
+ *
  */
 
 /*************************************************************************
@@ -8,7 +16,7 @@
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-v10.html
  *
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
@@ -35,8 +43,12 @@ extern "C" {
 #ifndef GVC_API
 #define GVC_API /* nothing */
 #endif
+
+/// @defgroup gvc_api Graphviz context library (GVC) API
+/// @ingroup public_apis
+/// @{
 	
-#define LAYOUT_DONE(g) (agbindrec(g, "Agraphinfo_t", 0, TRUE) && GD_drawing(g))
+#define LAYOUT_DONE(g) (agbindrec(g, "Agraphinfo_t", 0, true) && GD_drawing(g))
 
 /* misc */
 /* FIXME - this needs eliminating or renaming */
@@ -104,11 +116,8 @@ GVC_API int gvFreeContext(GVC_t *gvc);
  * freeing each item, then the list.
  * Returns NULL on error, or if there are no plugins.
  * In the former case, sz is unchanged; in the latter, sz = 0.
- *
- * At present, the str argument is unused, but may be used to modify
- * the search as in gvplugin_list above.
  */
-GVC_API char** gvPluginList (GVC_t *gvc, const char* kind, int* sz, char*);
+GVC_API char **gvPluginList(GVC_t *gvc, const char *kind, int *sz);
 
 /** Add a library from your user application
  * @param gvc Graphviz context to add library to
@@ -121,6 +130,8 @@ GVC_API void gvAddLibrary(GVC_t *gvc, gvplugin_library_t *lib);
  */
 GVC_API int gvToolTred(graph_t *g);
 
+/// @}
+
 #undef GVC_API
 
 #ifdef __cplusplus
